/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@commerce-apps/core");
exports.ClientConfig = core_1.ClientConfig;
const lodash_1 = tslib_1.__importDefault(require("lodash"));
/**
 * Instantiate a Client object with desired ClientConfig to perform operations
 * available in this API client.
 *
 * Note: When performing operations that require ShopperJWT authentication, an
 * Authorization header containing a JWT can be added to the headers field of the
 * ClientConfig object. The Client will use that Authorization header for all the
 * operations it is used to perform.
 */
class Client extends core_1.BaseClient {
  constructor(config) {
    super(config);
    if (!!!config.baseUri) {
      this.clientConfig.baseUri = "https://ai.salesforce.com/v3";
    }
  }
  /**
   * Tells the Einstein engine when a user views a product.
   */
  sendViewProduct(options) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      siteId: parameters["siteId"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    // @ts-ignore
    return core_1.StaticClient.post({
      client: this,
      rawResponse: (options || {}).rawResponse,
      path: "/activities/{siteId}/viewProduct",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers,
      body: (options || {}).body
    });
  }
  /**
   * Tells the Einstein engine when a user views a set of recommendations
   */
  sendViewReco(options) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      siteId: parameters["siteId"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    // @ts-ignore
    return core_1.StaticClient.post({
      client: this,
      rawResponse: (options || {}).rawResponse,
      path: "/activities/{siteId}/viewReco",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers,
      body: (options || {}).body
    });
  }
  /**
   * Tells the Einstein engine when a user clicks on a recommendation
   */
  sendClickReco(options) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      siteId: parameters["siteId"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    // @ts-ignore
    return core_1.StaticClient.post({
      client: this,
      rawResponse: (options || {}).rawResponse,
      path: "/activities/{siteId}/clickReco",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers,
      body: (options || {}).body
    });
  }
  /**
   * Tells the Einstein engine when a user adds an item to their cart.
   */
  sendAddToCart(options) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      siteId: parameters["siteId"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    // @ts-ignore
    return core_1.StaticClient.post({
      client: this,
      rawResponse: (options || {}).rawResponse,
      path: "/activities/{siteId}/addToCart",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers,
      body: (options || {}).body
    });
  }
  /**
   * Get a list of recommenders that can be used in recommendation requests.
   */
  getRecommenders(options) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      siteId: parameters["siteId"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    // @ts-ignore
    return core_1.StaticClient.get({
      client: this,
      rawResponse: (options || {}).rawResponse,
      path: "/personalization/recommenders/{siteId}",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers
    });
  }
  /**
   * Get a set of recommendations
   */
  getRecommendations(options) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      siteId: parameters["siteId"],
      recommenderName: parameters["recommenderName"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    // @ts-ignore
    return core_1.StaticClient.post({
      client: this,
      rawResponse: (options || {}).rawResponse,
      path: "/personalization/recs/{siteId}/{recommenderName}",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers,
      body: (options || {}).body
    });
  }
  /**
   * Get a set of recommendations for a zone
   */
  getZoneRecommendations(options) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      siteId: parameters["siteId"],
      zoneName: parameters["zoneName"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    // @ts-ignore
    return core_1.StaticClient.post({
      client: this,
      rawResponse: (options || {}).rawResponse,
      path: "/personalization/{siteId}/zones/{zoneName}",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers,
      body: (options || {}).body
    });
  }
}
exports.Client = Client;
exports.default = Client;
//# sourceMappingURL=einsteinApiQuickStartGuide.js.map
